<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;

class Coz07200DistribuicaoDaRefeicaoCardapio extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $dataSourceName = 'distribuicao_refeicao_cardapio';
    protected $parameterBagColumns = array('NRDISTPROD', 'CDPRODUTO', 'NRORG','IDORIGEM', 'ID');

    public function __construct($crudService, $parameterBag, $dataSourceManager){
        $this->crudService          = $crudService;
        $this->parameterBag         = $parameterBag;
        $this->dataSourceManager    = $dataSourceManager;
    }

    public function retornaDistAgregClienteFormatado(Request\Filter $request, Response $response) {
        try {
            $oldFilterCriteria = $request->getFilterCriteria();
            $filterCriteria = new \Zeedhi\Framework\DataSource\FilterCriteria(
                $this->dataSourceName, $oldFilterCriteria->getConditions(), $oldFilterCriteria->getPage(), $oldFilterCriteria->getPageSize()
            );

            $newFilterCriteria = $this->crudService->populateParameterBag(
                $filterCriteria, $this->parameterBagColumns
            );
            $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);
            $dataSet = self::formataMascara($dataSource->getRows(), self::getObjectProviderType());

            $response->addDataSet(new DataSet('coz07200_distribuicao_refeicao_cardapio', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function formataMascara($rows, $object){
        for($i = 0; $i < count($rows); $i ++){
            $type = $rows[$i]['IDTPIJURCLIE'];
            if ($type) {
                $rows[$i]['IDTPIJURCLIE'] = $object[$type]['name'];
                $maskInscricao = $object[$type]['mask'];

                if ($maskInscricao) {
                    for ($j = 0; $j < strlen($rows[$i]['NRINSJURCLIE']); $j++) {
                        $maskInscricao[strpos($maskInscricao, "#")]
                            = $rows[$i]['NRINSJURCLIE'][$j];
                    }

                    $rows[$i]['NRINSJURCLIE'] = $maskInscricao;
                }
            }
        }

        return $rows;
    }

    public function getObjectProviderType() {

        return
            array(
                "F" => array(
                    "name" => "Física",
                    "mask" => "###.###.###-##"
                ),
                "J" => array(
                    "name" => "Jurídica",
                    "mask" => "##.###.###/####-##"
                ),
                "I" => array(
                    "name" => "Internacional",
                    "mask" => ""
                ),
                "O" => array(
                    "name" => "Outros",
                    "mask" => ""
                )
            );
    }

}